import request from '@/utils/request'

// 【 ezhizao-dms-p2 】这个名字对应的就是 nacos 中的服务的 id，必须用“-”分割
// 开发时，在 vite.config.js 中配置 /ezhizao-dms-p2，参考 /dev-api 的配置
// 生产时，在nginx中配置 /ezhizao-dms-p2，指定对应的 nacos 中的服务 id：/ezhizao-dms-p2

const baseUrl = import.meta.env.VITE_APP_P2_API

// 查询 p2 中的生产计划列表
export function getP2Plan(data) {
  return request({
    url: baseUrl + '/business/p2/getP2Plan',
    method: 'get',
    params: data
  })
}

// 查询p2中的产品表
export function getP2Product() {
  return request({
    url: baseUrl + '/business/inc10100/getP2Product',
    method: 'get',
    timeout: 200000
  })
}
// 查询p2中的产品表
export function getP2Process() {
  return request({
    url: baseUrl + '/business/sfc10300/getP2Process',
    method: 'get'
  })
}
// 查询p2中需要序检的工序
export function getP2NeedCheckProcess(type) {
  return request({
    url: baseUrl + '/business/sfc10300/getP2ProcessWrbz/' + type,
    method: 'get'
  })
}
// 查询p2中计划单的单批重量
export function getProductionLotAmount(data) {
  return request({
    url: baseUrl + '/business/sfc10500/getLotAmount',
    method: 'get',
    params: data
  })
}
// 查询productionPlan详细
export function getProductionPlan(id) {
  return request({
    url: baseUrl + '/business/productionPlan/' + id,
    method: 'get'
  })
}

// 新增productionPlan
export function saveProductionPlan(data) {
  return request({
    url: baseUrl + '/business/productionPlan',
    method: 'post',
    data: data
  })
}

// 修改productionPlan
export function updateProductionPlan(data) {
  return request({
    url: baseUrl + '/business/productionPlan',
    method: 'put',
    data: data
  })
}

// 删除productionPlan
export function delProductionPlan(id) {
  return request({
    url: baseUrl + '/business/productionPlan/' + id,
    method: 'delete'
  })
}
